#define PORT 5556
#define SERVER "127.0.0.1"

#include <config.h>
#include <gnutls/gnutls.h>

#ifdef _WIN32
# include <winsock.h>
# include <io.h>
# include <winbase.h>
# define close closesocket
#else
# include <sys/socket.h>
# include <netinet/in.h>
# include <arpa/inet.h>
# include <unistd.h>
# include <netdb.h>
# include <signal.h>
#endif

/* the number of elements in the priority structures.
 */
#define PRI_MAX 16

extern const char str_unknown[];

int print_info(gnutls_session state, const char *hostname);
void print_cert_info(gnutls_session state, const char *hostname);
void print_list(void);

void parse_comp(char **comp, int ncomp, int *comp_priority);
void parse_kx(char **kx, int nkx, int *kx_priority);
void parse_ctypes(char **ctype, int nctype, int *cert_type_priority);
void parse_macs(char **macs, int nmacs, int *mac_priority);
void parse_ciphers(char **ciphers, int nciphers, int *cipher_priority);
void parse_protocols(char **protocols, int protocols_size,
		     int *protocol_priority);
const char *raw_to_string(const unsigned char *raw, size_t raw_size);

void sockets_init(void);

#include "inet_ntop.h"
